@@ -18,11 +18,11 @@ from pecan.rest import RestController
 import wsmeext.pecan as wsme_pecan
 from wsme.exc import ClientSideError
 from wsme import Unset
-from libra.api.model.lbaas import LoadBalancer, db_session
-from libra.api.model.lbaas import Device, HealthMonitor
+from libra.common.api.lbaas import LoadBalancer, db_session
+from libra.common.api.lbaas import Device, HealthMonitor
 from libra.api.acl import get_limited_to_project
 from libra.api.model.validators import LBMonitorPut, LBMonitorResp
-from libra.api.library.gearman_client import submit_job
+from libra.common.api.gearman_client import submit_job
 from libra.api.library.exp import NotFound
 
 
@@ -220,7 +220,7 @@ class HealthMonitorController(RestController):
         with db_session() as session:
             query = session.query(
                 LoadBalancer, HealthMonitor
-                ).outerjoin(LoadBalancer.monitors).\
+            ).outerjoin(LoadBalancer.monitors).\
                 filter(LoadBalancer.tenantid == tenant_id).\
                 filter(LoadBalancer.id == self.lbid).\
                 filter(LoadBalancer.status != 'DELETED').\
